import os
import streamlit.components.v1 as components

_RELEASE = False  # Set to False during dev

if not _RELEASE:
    _component_func = components.declare_component(
        "custom_aggrid",
        url="http://localhost:3001",  # Frontend dev server
    )
else:
    build_dir = os.path.join(os.path.dirname(__file__), "frontend", "build")
    # build_dir = os.path.join(os.path.dirname(__file__), "../frontend/build")
    _component_func = components.declare_component(
        "custom_aggrid",
        path=build_dir
    )


def custom_aggrid(data, column_defs, filter_model=None, key=None):
    return _component_func(
        data=data,
        columnDefs=column_defs,
        filterModel=filter_model,
        key=key,
        default={}
    )



import streamlit as st
from my_component import my_component

# Add some test code to play with the component while it's in development.
# During development, we can run this just as we would any other Streamlit
# app: `$ streamlit run my_component/example.py`

st.subheader("Component with constant args")

# Create an instance of our component with a constant `name` arg, and
# print its output value.
num_clicks = my_component("World")
st.markdown("You've clicked %s times!" % int(num_clicks))

st.markdown("---")
st.subheader("Component with variable args")

# Create a second instance of our component whose `name` arg will vary
# based on a text_input widget.
#
# We use the special "key" argument to assign a fixed identity to this
# component instance. By default, when a component's arguments change,
# it is considered a new instance and will be re-mounted on the frontend
# and lose its current state. In this case, we want to vary the component's
# "name" argument without having it get recreated.
name_input = st.text_input("Enter a name", value="Streamlit")
num_clicks = my_component(name_input, key="foo")
st.markdown("You've clicked %s times!" % int(num_clicks))



from setuptools import setup, find_packages

setup(
    name="filter-persist",  # your package name here
    version="0.1.0",
    description="Custom Streamlit AgGrid component",
    author="Parshav Shivnani",
    packages=["filter_persist"], # Package folder name with underscore
    include_package_data=True,
    install_requires=[
        "streamlit>=1.0",
    ],
    package_data={
        "my_component": ["frontend/build/**/*"],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)
